@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.26";
+our $VERSION = "0.27";
 
 =encoding utf-8
 
@@ -16,7 +16,7 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =head1 DESCRIPTION
 
@@ -320,7 +320,8 @@ use Hash::Util qw(lock_keys);
 use Unicode::EastAsianWidth;
 
 use Exporter 'import';
-our @EXPORT_OK = qw(&opt);
+our @EXPORT_OK = qw($VERSION &opt);
+our @EXPORT_TAGS = ( all => [ qw($VERSION) ] );
 
 our %opt = (
     engine   => \(our $xlate_engine),
@@ -539,7 +540,7 @@ builtin xlate-maxlen=i     $max_length
 builtin deepl-auth-key=s   $App::Greple::xlate::deepl::auth_key
 builtin deepl-method=s     $App::Greple::xlate::deepl::method
 
-option default --face +E --ci=A
+option default --ci=A --cm=/L22E,/L24E
 
 option --xlate-setopt --prologue &__PACKAGE__::setopt($<shift>)
 
